/*
This function will return either the beginning or end of a string, dividing it wherever it finds a backslash

Usage:
newString = [start, keepSide, keepSlash, oldString] call HOMJ_CullBackslash;

Where:
start = "LEFT" or "RIGHT", meaning the script will start on this side of the string and look for "\" in the other direction
keepSide = "LEFT" or "RIGHT", meaning which side of the found backslash you wish to keep
keepSlash = TRUE or FALSE, meaning whether or not to include the backslash in the return value

Examples:
_filename = ["RIGHT", "RIGHT", FALSE, "c:\myPath\someFile.txt"] call HOMJ_CullBackslash;
returns: "someFile.txt"

_pathname = ["RIGHT", "LEFT", TRUE, "c:\a path\a file.txt"] call HOMJ_CullBackslash;
returns: "c:\myPath\"
*/

private ["_skip", "_start", "_keep", "_string", "_backslash", "_keepFunc", "_i", "_j"];

_start = _this select 0; // Side to start on, LEFT or RIGHT
_keep = _this select 1; // Side to keep, LEFT or RIGHT
if (_this select 2) then {_skip = 1} else {_skip = 0}; // Whether or not to keep the backslash in the returned result
_string = toArray(_this select 3); // The input string
_backslash = ((toArray "\") select 0); // The backslash character code to look for

_keepFunc = {
	_i = _this;
	if (_keep == "LEFT") then { // Delete all the stuff to the right of the backslash:
		for [{_j=_i+_skip}, {_j<=(count _string - 1)}, {_j=_j+1}] do {
			_string set [_j, "DELETE"];
		};
	} else { // Delete all the stuff to the left of the backslash:
		for [{_j=_i-_skip}, {_j>=0}, {_j=_j-1}] do {
			_string set [_j, "DELETE"];
		};
	};
	_string = _string - ["DELETE"];
};

if (_start == "LEFT") then { // Start at the left side of the string with iterator "_i" and work right
	for [{_i=0}, {_i<(count _string - 1)}, {_i=_i+1}] do {
		if ((_string select _i) == _backslash) exitWith { // If a backslash is found, stop iterating
			_i call _keepFunc;
		};
	};
} else { // Start at the right side of the string with iterator "_i" and work left
	for [{_i=(count _string - 1)}, {_i>0}, {_i=_i-1}] do {
		if ((_string select _i) == _backslash) exitWith { // If a backslash is found, stop iterating
			_i call _keepFunc;
		};
	};
};

(toString _string)