/*
This script executes when a +, T, or | button is pressed

This script:
- hides key part fields
- shows CANCEL (to be done later on)
- spawns piece
- positions piece at HOMJ_WorldPos (mouse cursor location) constantly
- waits for mouse clicks for position & direction

later on: left clicks can move keyparts, right clicks can rotate them

reference info:

!!!!!prefix does NOT contain underscore!!!!!

straight:		<prefix>_6
terminator:	<prefix>_6konec
T:			kr_t_<prefix>_<prefix>
X:			kt_x_<prefix>_<prefix>
*/

private ["_type", "_sides", "_roadDir", "_road", "_center", "_roadPos", "_endPos", "_basePrefix", "_curSection"];

_GetTypeSides = {
	switch (_this select 0) do {
		case "+": {_type = "NULL"; _sides = 4;};
		case "T": {_type = "NULL"; _sides = 3;};
		case "|": {
			_type = format ["HOMJ_%1%2", _this select 1, "6"];
			_sides = [[0,0, 180], [0,6.25, 0]]; // each array marks a connection point: [x, y, direction] all given as relative coordinates from the origin point of the road piece
		};
		case "|t": {
			_type = format ["HOMJ_%1%2", _this select 1, "6konec"];
			_sides = [[0,6.25, 0]];
		};
	};
	[_type, _sides]
};


_AddToCurrent = {
	HOMJ_RoadPainter_Stop = true;
	call compile format ["_curSection = %1", HOMJ_RoadPainter_SectionCurrent];
	_roadPos = (((_curSection select (count _curSection - 1)) select 5) select 0);
	_roadDir = (((_curSection select (count _curSection - 1)) select 5) select 1) + 180;
	_road = createVehicle [_this, [0,0,0], [], 0, ""];

	_road setDir (_roadDir);
	_road setPos [(_roadPos select 0) - 6.25*sin(_roadDir), (_roadPos select 1) - 6.25*cos(_roadDir)];
	_roadPos = position _road;
};


_PlaceNew = {
	// spawn keypart piece:
	_road = createVehicle [_this, [0,0,0], [], 0, ""];

	if (isNull _road) exitWith {[format ["INVALID ROAD PREFIX ""%1"" - CHECK SPELLING", (lbText [19867, lbCurSel 19867])]] execVM "scripts\HOMJ_RoadPainter_ThrowError.sqf";};

	// position keypart piece:
	HOMJ_RoadPainter_PlacingKeypart = true;
	while {HOMJ_RoadPainter_PlacingKeypart} do {
		sleep 0.01;
		_road setPos HOMJ_WorldPos;
	};
	_roadPos = HOMJ_WorldPos;
	// set keypard piece direction:
	HOMJ_RoadPainter_PlacingKeypart = true;
	while {HOMJ_RoadPainter_PlacingKeypart} do {
		
		_roadDir = [_roadPos, HOMJ_WorldPos] call dirToPos;
		_roadDir = 10*round(_roadDir/10);

		_road setDir _roadDir;
		_road setPos _roadPos;

		sleep 0.01;
	};
};

_Main = {
	_prefix = ["RIGHT", "RIGHT", FALSE, (lbText [19867, lbCurSel 19867])] call HOMJ_CullBackslash; // gets the prefix for the road type, e.g. asf1_
	_type = [_this, _prefix] call _GetTypeSides; // gets the full classname for the keypart, e.g. HOMJ_asf1_6konec. Returns "NULL" if a non-working type is selected (cross or tee)
	if ((_type select 0) == "NULL") exitWith {["THIS TYPE DOESN'T WORK YET"] execVM "scripts\HOMJ_RoadPainter_ThrowError.sqf";};

	"HIDE" execVM "scripts\HOMJ_RoadPainter_ToggleKeyPartDialog.sqf";
	["CLICK ON THE GROUND TO PLACE YOUR PART, THEN CLICK TO SET ITS DIRECTION"] execVM "scripts\HOMJ_RoadPainter_ThrowMessage.sqf";
	
	if (HOMJ_RoadPainter_Painting) then {
		(_type select 0) call _AddToCurrent;
	} else {
		(_type select 0) call _PlaceNew;
	};
	HOMJ_RoadPainter_PlacingKeypart = false;
	_endPos = [(_roadPos select 0) + 6.25*sin(_roadDir), (_roadPos select 1) + 6.25*cos(_roadDir), 0];
	_center = [((_roadPos select 0) + (_endPos select 0)) / 2, ((_roadPos select 1) + (_endPos select 1)) / 2];
	HOMJ_RoadPainter_Keyparts = HOMJ_RoadPainter_Keyparts + [[_road, _center, [_roadPos, _endPos], (_type select 1), (lbText [19867, lbCurSel 19867])]];
	[""] execVM "scripts\HOMJ_RoadPainter_ThrowMessage.sqf";
};

call _Main;
